packer {
  required_plugins {
    qemu = {
      version = ">= 1.0.0"
      source  = "github.com/hashicorp/qemu"
    }
  }
}

variable "ubuntu_iso_url" {
  type    = string
  default = "https://releases.ubuntu.com/22.04/ubuntu-22.04.4-live-server-amd64.iso"
}

variable "ubuntu_iso_checksum" {
  type    = string
  default = "sha256:..." # zkontroluj hash z oficiální stránky
}

source "qemu" "ubuntu" {
  iso_url            = var.ubuntu_iso_url
  iso_checksum       = var.ubuntu_iso_checksum
  output_directory   = "output/ubuntu"
  shutdown_command   = "echo 'packer' | sudo -S shutdown -P now"
  communicator       = "ssh"
  ssh_username       = "ubuntu"
  ssh_password       = "ubuntu"
  ssh_wait_timeout   = "20m"

  disk_interface     = "virtio"
  format             = "qcow2"
  accelerator        = "hvf" # macOS, jinak např. kvm
  headless           = true
  boot_wait          = "10s"
  boot_command = [
    "<esc><wait>",
    "autoinstall ds=nocloud-net;s=http://{{ .HTTPIP }}:{{ .HTTPPort }}/<enter>"
  ]

  http_directory = "http"
}

build {
  sources = ["source.qemu.ubuntu"]
}